<?php
/**
 * oneloginbiz: Customizer
 *
 * @package WordPress
 * @subpackage oneloginbiz
 * @since 1.0
 */

function oneloginbiz_customize_register( $wp_customize ) {

	/* Custom panel type - used for multiple levels of panels */
	if ( class_exists( 'WP_Customize_Panel' ) ) {

		/**
		 * Class Oneloginbiz_WP_Customize_Panel
		 */
		class Oneloginbiz_WP_Customize_Panel extends WP_Customize_Panel {

			/**
			 * Panel
			 *
			 * @var $panel string Panel
			 */
			public $panel;

			/**
			 * Panel type
			 *
			 * @var $type string Panel type.
			 */
			public $type = 'oneloginbiz_panel';

			/**
			 * Form the json
			 */
			public function json() {

				$array                   = wp_array_slice_assoc(
					(array) $this, array(
						'id',
						'description',
						'priority',
						'type',
						'panel',
					)
				);
				$array['title']          = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
				$array['content']        = $this->get_content();
				$array['active']         = $this->active();
				$array['instanceNumber'] = $this->instance_number;

				return $array;

			}

		}

	}

	$wp_customize->register_panel_type( 'oneloginbiz_WP_Customize_Panel' );

	/**
	 * Upsells
	 */
	load_template( trailingslashit( get_template_directory() ) . 'inc/class-customizer-theme-info-control.php' );


	$wp_customize->add_panel( 'oneloginbiz_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'oneloginbiz' ),
	    'description' => __( 'Description of what this panel does.', 'oneloginbiz' ),
	) );

	// Social Icons
	$wp_customize->add_section( 'oneloginbiz_contact_details', array(
    	'title'      => __( 'Social Icons', 'oneloginbiz' ),
		'priority'   => null,
		'panel' => 'oneloginbiz_panel_id'
	) );

	$wp_customize->add_setting('oneloginbiz_facebook',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('oneloginbiz_facebook',array(
		'label'	=> __('Add Facebook link','oneloginbiz'),
		'section'=> 'oneloginbiz_contact_details',
		'setting'=> 'oneloginbiz_facebook',
		'type'=> 'url'
	));

	$wp_customize->add_setting('oneloginbiz_twitter',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('oneloginbiz_twitter',array(
		'label'	=> __('Add Twitter Link','oneloginbiz'),
		'section'=> 'oneloginbiz_contact_details',
		'setting'=> 'oneloginbiz_twitter',
		'type'=> 'url'
	));

	$wp_customize->add_setting('oneloginbiz_linkdin',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('oneloginbiz_linkdin',array(
		'label'	=> __('Add Linkdin Link','oneloginbiz'),
		'section'=> 'oneloginbiz_contact_details',
		'setting'=> 'oneloginbiz_linkdin',
		'type'=> 'url'
	));	

	$wp_customize->add_setting('oneloginbiz_instagram',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('oneloginbiz_instagram',array(
		'label'	=> __('Add Instagram Link','oneloginbiz'),
		'section'=> 'oneloginbiz_contact_details',
		'setting'=> 'oneloginbiz_instagram',
		'type'=> 'url'
	));

	//home page slider
	$wp_customize->add_section( 'oneloginbiz_slider_section' , array(
    	'title'      => __( 'Slider Settings', 'oneloginbiz' ),
		'priority'   => null,
		'panel' => 'oneloginbiz_panel_id'
	) );

	$wp_customize->add_setting('oneloginbiz_slider_arrows',array(
	       'default' => 'true',
	       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('oneloginbiz_slider_arrows',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide slider','oneloginbiz'),
       'section' => 'oneloginbiz_slider_section',
    ));


	for ( $count = 1; $count <= 2; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'oneloginbiz_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'oneloginbiz_sanitize_dropdown_pages'
		) );

		$wp_customize->add_control( 'oneloginbiz_slider' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'oneloginbiz' ),
			'section'  => 'oneloginbiz_slider_section',
			'type'     => 'dropdown-pages'
		) );

	}
	//Post

	
	$post_list = get_posts();
	$i = 0;	
	$pst[]='Select';
	foreach ($post_list as $key => $p_post) {
		$pst[$p_post->ID]=$p_post->post_title;
	}
	for ( $s = 3; $s <= 4; $s++ ) {

		$wp_customize->add_setting('oneloginbiz_post_setting'.$s,array(
			'sanitize_callback' => 'oneloginbiz_sanitize_choices',
		));
		$wp_customize->add_control('oneloginbiz_post_setting'.$s,array(
			'type'    => 'select',
			'choices' => $pst,
			'label' => __('Select post','oneloginbiz'),
			'section' => 'oneloginbiz_slider_section',
		));
	}

	//home page slider1
	$wp_customize->add_section( 'oneloginbiz_slider_section1' , array(
    	'title'      => __( 'Slider Settings 1', 'oneloginbiz' ),
		'priority'   => null,
		'panel' => 'oneloginbiz_panel_id'
	) );

	$wp_customize->add_setting('oneloginbiz_slider_arrows1',array(
	       'default' => 'true',
	       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('oneloginbiz_slider_arrows1',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide slider','oneloginbiz'),
       'section' => 'oneloginbiz_slider_section1',
    ));


	for ( $count = 1; $count <= 2; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'oneloginbiz_slider1' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'oneloginbiz_sanitize_dropdown_pages'
		) );

		$wp_customize->add_control( 'oneloginbiz_slider1' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'oneloginbiz' ),
			'section'  => 'oneloginbiz_slider_section1',
			'type'     => 'dropdown-pages'
		) );

	}
	//Post


	$post_list = get_posts();
	$i = 0;	
	$pst_sls[]='Select';
	foreach ($post_list as $key => $p_post) {
		$pst_sls[$p_post->ID]=$p_post->post_title;
	}
	for ( $s = 3; $s <= 4; $s++ ) {
		$wp_customize->add_setting('oneloginbiz_post_setting1'.$s,array(
			'sanitize_callback' => 'oneloginbiz_sanitize_choices',
		));
		$wp_customize->add_control('oneloginbiz_post_setting1'.$s,array(
			'type'    => 'select',
			'choices' => $pst_sls,
			'label' => __('Select post','oneloginbiz'),
			'section' => 'oneloginbiz_slider_section1',
		));
	}

	// category section
	$wp_customize->add_section( 'oneloginbiz_service_section', array(
    	'title'      => __( 'Category Section', 'oneloginbiz' ),
		'priority'   => null,
		'panel' => 'oneloginbiz_panel_id'
	) );

	$wp_customize->add_setting('oneloginbiz_service_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	

	$wp_customize->add_control('oneloginbiz_service_title',array(
		'label'	=> __('Section Title','oneloginbiz'),
		'section'	=> 'oneloginbiz_service_section',
		'setting'	=> 'oneloginbiz_service_title',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('oneloginbiz_service_description',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	

	$wp_customize->add_control('oneloginbiz_service_description',array(
		'label'	=> __('Description','oneloginbiz'),
		'section'	=> 'oneloginbiz_service_section',
		'setting'	=> 'oneloginbiz_service_description',
		'type'		=> 'text'
	));

	// Project Types
	$wp_customize->add_setting( 'oneloginbiz_category_section_setting', array(
		'type'       => 'theme_mod',
		'capability' => 'edit_theme_options',
		'transport'  => '',
		'sanitize_callback' => 'oneloginbiz_project_types_sanitize'
	) );

	$wp_customize->add_control(
		new Oneloginbiz_Customize_Control_Multiple_Select(
			$wp_customize,
			'oneloginbiz_category_section_setting',
			array(
				'settings' => 'oneloginbiz_category_section_setting',
				'label'    => 'Select which project types you want to exclude from the home page',
				'section'  => 'oneloginbiz_service_section', // Enter the name of your own section
				'type'     => 'multiple-select', // The $type in our class
				'choices'  => oneloginbiz_project_types() // Your choices
			)
		)
	);

	// Shop Section
	$wp_customize->add_section('oneloginbiz_service',array(
		'title'	=> __('Shop Section','oneloginbiz'),
		'panel' => 'oneloginbiz_panel_id',
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
	if($i==0){
	$default = $category->slug;
	$i++;
	}
	$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('oneloginbiz_category_setting',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('oneloginbiz_category_setting',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Post','oneloginbiz'),
		'section' => 'oneloginbiz_service',
	));

	//Single post
		$wp_customize->add_section('oneloginbiz_post',array(
			'title'	=> __('Single Post','oneloginbiz'),			
			'panel' => 'oneloginbiz_panel_id',
		));

		$post_list = get_posts();
		$i = 0;
		$pst_slsls[]='Select';	
		foreach($post_list as $post){
			$pst_slsls[$post->post_title] = $post->post_title;
		}
		$wp_customize->add_setting('oneloginbiz_single_post',array(
			'sanitize_callback' => 'oneloginbiz_sanitize_choices',
		));
		$wp_customize->add_control('oneloginbiz_single_post',array(
			'type'    => 'select',
			'choices' => $pst_slsls,
			'label' => __('Select post','oneloginbiz'),
			'section' => 'oneloginbiz_post',
		));

		//Design post
		$wp_customize->add_section('oneloginbiz_design_section',array(
			'title'	=> __('Design Post','oneloginbiz'),			
			'panel' => 'oneloginbiz_panel_id',
		));


		$post_list = get_posts();
		$i = 0;
		$pst_slslsl[]='Select';	
		foreach($post_list as $post){
			$pst_slslsl[$post->post_title] = $post->post_title;
		}

		$wp_customize->add_setting('oneloginbiz_design_section_post',array(
			'sanitize_callback' => 'oneloginbiz_sanitize_choices',
		));
		$wp_customize->add_control('oneloginbiz_design_section_post',array(
			'type'    => 'select',
			'choices' => $pst_slslsl,
			'label' => __('Select post','oneloginbiz'),
			'section' => 'oneloginbiz_design_section',
		));

	//Footer
    $wp_customize->add_section( 'oneloginbiz_footer', array(
    	'title'      => __( 'Footer Text', 'oneloginbiz' ),
		'priority'   => null,
		'panel' => 'oneloginbiz_panel_id'
	) );

    $wp_customize->add_setting('oneloginbiz_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('oneloginbiz_footer_copy',array(
		'label'	=> __('Footer Text','oneloginbiz'),
		'section'	=> 'oneloginbiz_footer',
		'setting'	=> 'oneloginbiz_footer_copy',
		'type'		=> 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'oneloginbiz_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'oneloginbiz_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'oneloginbiz_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'oneloginbiz_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'oneloginbiz' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'oneloginbiz' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'oneloginbiz_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'oneloginbiz_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'oneloginbiz_customize_register' );

function oneloginbiz_sanitize_colorscheme( $input ) {
	$valid = array( 'light', 'dark', 'custom' );

	if ( in_array( $input, $valid, true ) ) {
		return $input;
	}

	return 'light';
}

function oneloginbiz_customize_partial_blogname() {
	bloginfo( 'name' );
}

function oneloginbiz_customize_partial_blogdescription() {
	bloginfo( 'description' );
}


function oneloginbiz_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}

function oneloginbiz_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Oneloginbiz_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );
		
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'oneloginbiz-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'oneloginbiz-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
	
}

// Doing this customizer thang!
Oneloginbiz_Customize::get_instance();